@@ -36,7 +36,7 @@ class App:
     )
     icon = QIcon(icon_path)
 
-    notify_callback = None
+    hide_callback = []
 
     @classmethod
     def run(cls):
@@ -53,12 +53,12 @@ class App:
         """Construct the application."""
         logging.debug("Building application.")
         cls.app.setApplicationName("Timecard")
-        cls.app.setApplicationVersion('2.0.7')
+        cls.app.setApplicationVersion('2.1.0')
         cls.app.setDesktopFileName('com.codemouse92.timecard')
         cls.app.setWindowIcon(cls.icon)
 
         logging.debug("Building main window.")
-        cls.window.resize(400, 400)
+        cls.window.resize(500, 400)
         cls.window.setLayout(cls.layout)
 
     @classmethod
@@ -72,12 +72,15 @@ class App:
     def show_window(cls):
         """Display the main window."""
         cls.window.show()
+        cls.window.activateWindow()
+        cls.window.raise_()
 
     @classmethod
     def hide_window(cls):
         """Hide the main window."""
         cls.window.hide()
-        cls.notify("Timecard is still running in the notification area.")
+        for callback in cls.hide_callback:
+            callback("Timecard is still running in the notification area.")
 
     @classmethod
     def add_widget(cls, widget):
@@ -85,14 +88,9 @@ class App:
         cls.layout.addWidget(widget)
 
     @classmethod
-    def notify(cls, message):
-        if cls.notify_callback:
-            cls.notify_callback(message)
-
-    @classmethod
-    def connect(cls, notify=None):
-        if notify:
-            cls.notify_callback = notify
+    def connect(cls, on_hide=None):
+        if on_hide and on_hide not in cls.hide_callback:
+            cls.hide_callback.append(on_hide)
 
     @classmethod
     def quit(cls):
