@@ -18,6 +18,11 @@ class Notes:
                                    "This will be saved with the log entry.")
         return cls.txt_notes
 
+    @classmethod
+    def restore_from_backup(cls, notes):
+        """Sets value from backup."""
+        cls.txt_notes.setText(notes)
+
     @classmethod
     def get_text(cls):
         """Returns the current text in the notes box."""
